==> pam_tcfs-1.0.tar.gz: pam_tcfs-1.0/src/tcfs_getpwnam.c <==
/*
 *      pam_tcfs.so v1.0
 *
 *      written by Luigi Catuogno [luicat@mikonos.dia.unisa.it]
 *
 *      Jun 30 1997
 */

#include<stdio.h>
#include<syslog.h>
#include<strings.h>
#include<sys/types.h>
#include<fcntl.h>
#include"tcfspasswd.h"


struct tcfspasswd *tcfs_strgetpwnam(char *str, struct tcfspasswd *dest)
{
	static char *v[NumOfField],**a,*i;
	struct tcfspasswd *r;

	r=NULL;
	if (!str) 
		return NULL;

	i=str;
	if(!dest)
		{
		 r=(struct tcfspasswd*)malloc(sizeof(struct tcfspasswd));
		 if(!r)
			{
			 syslog(LOG_ERR,"malloc failed");
			 exit(1);
			}
		}
	else
		r=dest;

	bzero(r->uid,MaxUserLen);
	bzero(r->upw,UUKEYSIZE);


	for (a=v;(*a=strsep(&i,":"))!=NULL;)
		if(**a!='\0')
			++a;
		else
			(*(*a-1)='\0'),++a;
	
	strncpy(r->uid,v[0],strlen(v[0]));
	strncpy(r->upw,v[1],UUKEYSIZE);

	return r;
}

	
struct tcfspasswd *tcfs_getpwnam(char *u, struct tcfspasswd *dest)
{
	struct tcfspasswd *r;
	static char *var[2],**ap, *is;
	static char line[MaxLineLen];
	int done=0,lockf;
	
	FILE *pwdf;
	
	r=NULL;

	if ((lockf=open(TCFSPWDLOCK,O_RDONLY))!=-1)
		{
		 syslog(LOG_ERR,"tcfspasswd locked");
		 goto fine;
		}

	pwdf=fopen(TCFSPWDFILE,"r");
	if(!pwdf)
		{
		 syslog(LOG_ERR,"cannot open tcfspasswd file");
		 goto fine;
		}
	
	while(!feof(pwdf))
	{
		fgets(line,MaxLineLen,pwdf);
		if(feof(pwdf))
			break;

		is=line;
		for(ap=var;(*ap=strsep(&is,":"))!=NULL;)
			if(**ap!='\0')
				++ap;
			else
				(*(*ap-1)='\0'), ++ap;

		if(!strncmp(u,var[0],strlen(u))) 
			{
			 done=1;
			 break;
			}
	}

	fclose(pwdf);
	if(!done)
		 goto fine;

	if (!dest)
		{  
		 r=(struct tcfspasswd *)malloc(sizeof(struct tcfspasswd));
		 if(!r)
		   {
		    syslog(LOG_ERR,"malloc failed");
		    close(lockf);
		    unlink(TCFSPWDLOCK);
		    exit(1);
		   }
		}
	else
		{
		 r=dest;
		}
	
	bzero(r->uid,MaxUserLen);
	bzero(r->upw,UUKEYSIZE);
	strncpy(r->uid,var[0],strlen(var[0]));
	strncpy(r->upw,var[1],UUKEYSIZE);
fine:
	close(lockf);
	unlink(TCFSPWDLOCK);
	return r;
}

/*	Per compatibilita' con i vecchi sorgenti
*/


char *gettcfskey(char *login)
{
	return (tcfs_getpwnam(login,(struct tcfspasswd*)0)->upw);
}

==> pam_tcfs-1.0.1.tar.gz: pam_tcfs-1.0.1/src/tcfs_getpwnam.c <==
/*
 *      pam_tcfs.so v1.0.1
 *
 *      written by Luigi Catuogno [luicat@mikonos.dia.unisa.it]
 *
 *      Jul 2 1997
 */

#include<stdio.h>
#include<syslog.h>
#include<strings.h>
#include<sys/types.h>
#include<fcntl.h>
#include"tcfspasswd.h"


struct tcfspasswd *tcfs_strgetpwnam(char *str, struct tcfspasswd *dest)
{
	static char *v[NumOfField],**a,*i;
	struct tcfspasswd *r;

	r=NULL;
	if (!str) 
		return NULL;

	i=str;
	if(!dest)
		{
		 r=(struct tcfspasswd*)malloc(sizeof(struct tcfspasswd));
		 if(!r)
			{
			 syslog(LOG_ERR,"malloc failed");
			 exit(1);
			}
		}
	else
		r=dest;

	bzero(r->uid,MaxUserLen);
	bzero(r->upw,UUKEYSIZE);


	for (a=v;(*a=strsep(&i,":"))!=NULL;)
		if(**a!='\0')
			++a;
		else
			(*(*a-1)='\0'),++a;
	
	strncpy(r->uid,v[0],strlen(v[0]));
	strncpy(r->upw,v[1],strlen(v[1]));

	return r;
}

	
struct tcfspasswd *tcfs_getpwnam(char *u, struct tcfspasswd *dest)
{
	struct tcfspasswd *r;
	static char *var[2],**ap, *is;
	static char line[MaxLineLen];
	int done=0,lockf;
	
	FILE *pwdf;
	
	r=NULL;

	if ((lockf=open(TCFSPWDLOCK,O_RDONLY))!=-1)
		{
		 syslog(LOG_ERR,"tcfspasswd locked");
		 goto fine;
		}

	pwdf=fopen(TCFSPWDFILE,"r");
	if(!pwdf)
		{
		 syslog(LOG_ERR,"cannot open tcfspasswd file");
		 goto fine;
		}
	
	while(!feof(pwdf))
	{
		fgets(line,MaxLineLen,pwdf);
		if(feof(pwdf))
			break;

		is=line;
		for(ap=var;(*ap=strsep(&is,":"))!=NULL;)
			if(**ap!='\0')
				++ap;
			else
				(*(*ap-1)='\0'), ++ap;

		if(!strncmp(u,var[0],strlen(u))) 
			{
			 done=1;
			 break;
			}
	}

	fclose(pwdf);
	if(!done)
		 goto fine;

	if (!dest)
		{  
		 r=(struct tcfspasswd *)malloc(sizeof(struct tcfspasswd));
		 if(!r)
		   {
		    syslog(LOG_ERR,"malloc failed");
		    close(lockf);
		    unlink(TCFSPWDLOCK);
		    exit(1);
		   }
		}
	else
		{
		 r=dest;
		}
	
	bzero(r->uid,MaxUserLen);
	bzero(r->upw,UUKEYSIZE);
	strncpy(r->uid,var[0],strlen(var[0]));
	strncpy(r->upw,var[1],strlen(var[1]));
fine:
	close(lockf);
	unlink(TCFSPWDLOCK);
	return r;
}

/*	Per compatibilita' con i vecchi sorgenti
*/


char *gettcfskey(char *login)
{
	return (tcfs_getpwnam(login,(struct tcfspasswd*)0)->upw);
}
